@@ -31,8 +31,8 @@ search_makefilter <- function( x,
 						 filterTierExcludeRegEx       =NULL) {
 	
 	
-	if (missing(x)) 	{stop("Corpus object in parameter 'x' is missing.") 		} else { if (class(x)[[1]]!="corpus") 		{stop("Parameter 'x' needs to be a corpus object.") 	} }
-
+	if (missing(x)) 	{stop("Corpus object in parameter 'x' is missing.") 		}	else { if (!methods::is(x,"corpus")   )	{stop("Parameter 'x' needs to be a corpus object.") } }
+	
 	# x<-corpus
 	# filterTranscriptNames<-NULL
 	# filterTranscriptIncludeRegEx<-NULL
